libname out "c:\ethanol\feb05\renorm\aicc";
libname feb "c:\ethanol\feb05\renorm";

OPTIONS LS=79 ps=59;

proc datasets library=out;
delete ichigher10;
run;


/* MACRO to run mixed model variants */
/* In all these cases, fixed and random interaction terms are the same (no weights)
so we don't need to have fterms and rterms in macro calls  */

%macro runmix(data, method, code, fterms, extra);


PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ic ;
CLASS NEW;
TITLE "Code &code : NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU RVOX T9OL RVT5 RVSU RVT9 AROX AROL T5OL RVRV
               &fterms
               /S DDFM=RES;

RANDOM         int RV T5 T9 AR OL OX SU RVOX T9OL RVT5 RVSU RVT9 AROX AROL T5OL RVRV
               &fterms
               /SUB=NEW;
ods output infocrit=ic;
run;

data ichigher;
set ic;
length modcode $ 5;
modcode="&code";
run;

proc append base=out.ichigher10 data=ichigher;
run;


%mend runmix;


%macro main;

    %runmix(feb.higher, ml, 0, , );
    %runmix(feb.higher, ml, 10a, rvar, rvar);
    %runmix(feb.higher, ml, 10b, rvol, rvol);
*    %runmix(feb.higher, ml, 10c, rvox, rvox);
*    %runmix(feb.higher, ml, 10d, rvrv, rvrv);
*    %runmix(feb.higher, ml, 10e, rvsu, rvsu);
*    %runmix(feb.higher, ml, 10f, rvt5, rvt5);
*    %runmix(feb.higher, ml, 10g, rvt9, rvt9);
    %runmix(feb.higher, ml, 10h, t5ar, t5ar);
*    %runmix(feb.higher, ml, 10i, t5ol, t5ol);
    %runmix(feb.higher, ml, 10j, t5ox, t5ox);
    %runmix(feb.higher, ml, 10k, t5su, t5su);
    %runmix(feb.higher, ml, 10l, t5t5, t5t5);
    %runmix(feb.higher, ml, 10m, t5t9, t5t9);
    %runmix(feb.higher, ml, 10n, t9ar, t9ar);
*    %runmix(feb.higher, ml, 10o, t9ol, t9ol);
    %runmix(feb.higher, ml, 10p, t9ox, t9ox);
    %runmix(feb.higher, ml, 10q, t9su, t9su);
    %runmix(feb.higher, ml, 10r, t9t9, t9t9);
    %runmix(feb.higher, ml, 10s, arar, arar);
*    %runmix(feb.higher, ml, 10t, arol, arol);
*    %runmix(feb.higher, ml, 10u, arox, arox);
    %runmix(feb.higher, ml, 10v, arsu, arsu);
    %runmix(feb.higher, ml, 10w, olol, olol);
    %runmix(feb.higher, ml, 10x, olox, olox);
    %runmix(feb.higher, ml, 10y, olsu, olsu);
    %runmix(feb.higher, ml, 10z, suox, suox);
    %runmix(feb.higher, ml, 10*, susu, susu);
    %runmix(feb.higher, ml, 10+, oxox, oxox);


proc means data=out.ichigher10 noprint;
var aicc;
output out=minic minid(aicc (aicc modcode))=minaicc mincode;
run;

proc print data=minic;
run;

%mend main;

%main
