libname out "c:\ethanol\feb05\renorm\aicc";
libname feb "c:\ethanol\feb05\renorm";

OPTIONS LS=79 ps=59;

proc datasets library=out;
delete ichigher3;
run;


/* MACRO to run mixed model variants */
/* In all these cases, fixed and random interaction terms are the same (no weights)
so we don't need to have fterms and rterms in macro calls  */

%macro runmix(data, method, code, fterms, extra);


PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ic ;
CLASS NEW;
TITLE "Code &code : NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU RVOX T9OL
               &fterms
               /S DDFM=RES;

RANDOM         int RV T5 T9 AR OL OX SU RVOX T9OL
               &fterms
               /SUB=NEW;
ods output infocrit=ic;
run;

data ichigher;
set ic;
length modcode $ 5;
modcode="&code";
run;

proc append base=out.ichigher3 data=ichigher;
run;


%mend runmix;


%macro main;

    %runmix(feb.higher, ml, 0, , );
    %runmix(feb.higher, ml, 3a, rvar, rvar);
    %runmix(feb.higher, ml, 3b, rvol, rvol);
*    %runmix(feb.higher, ml, 3c, rvox, rvox);
    %runmix(feb.higher, ml, 3d, rvrv, rvrv);
    %runmix(feb.higher, ml, 3e, rvsu, rvsu);
    %runmix(feb.higher, ml, 3f, rvt5, rvt5);
    %runmix(feb.higher, ml, 3g, rvt9, rvt9);
    %runmix(feb.higher, ml, 3h, t5ar, t5ar);
    %runmix(feb.higher, ml, 3i, t5ol, t5ol);
    %runmix(feb.higher, ml, 3j, t5ox, t5ox);
    %runmix(feb.higher, ml, 3k, t5su, t5su);
    %runmix(feb.higher, ml, 3l, t5t5, t5t5);
    %runmix(feb.higher, ml, 3m, t5t9, t5t9);
    %runmix(feb.higher, ml, 3n, t9ar, t9ar);
*    %runmix(feb.higher, ml, 3o, t9ol, t9ol);
    %runmix(feb.higher, ml, 3p, t9ox, t9ox);
    %runmix(feb.higher, ml, 3q, t9su, t9su);
    %runmix(feb.higher, ml, 3r, t9t9, t9t9);
    %runmix(feb.higher, ml, 3s, arar, arar);
    %runmix(feb.higher, ml, 3t, arol, arol);
    %runmix(feb.higher, ml, 3u, arox, arox);
    %runmix(feb.higher, ml, 3v, arsu, arsu);
    %runmix(feb.higher, ml, 3w, olol, olol);
    %runmix(feb.higher, ml, 3x, olox, olox);
    %runmix(feb.higher, ml, 3y, olsu, olsu);
    %runmix(feb.higher, ml, 3z, suox, suox);
    %runmix(feb.higher, ml, 3*, susu, susu);
    %runmix(feb.higher, ml, 3+, oxox, oxox);


proc means data=out.ichigher3 noprint;
var aicc;
output out=minic minid(aicc (aicc modcode))=minaicc mincode;
run;

proc print data=minic;
run;

%mend main;

%main
