libname out "c:\ethanol\feb05\renorm\aicc";
libname feb "c:\ethanol\feb05\renorm";

OPTIONS LS=79 ps=59;

proc contents data=feb.normal;
run;

proc datasets library=out;
delete icnormal11;
run;


/* MACRO to run mixed model variants */
/* In all these cases, fixed and random interaction terms are the same (no weights)
so we don't need to have fterms and rterms in macro calls  */

%macro runmix(data, method, code, fterms, extra);


PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ic ;
CLASS NEW;
TITLE "Code &code : NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU T9OX OXOX SUOX T5T5 T9AR RVAR RVOX OLOL RVT9 T9SU
               &fterms
               /S DDFM=RES;

RANDOM         int RV T5 T9 AR OL OX SU T9OX OXOX SUOX T5T5 T9AR RVAR RVOX OLOL RVT9 T9SU
               &fterms
               /SUB=NEW;
ods output infocrit=ic;
run;

data icnormal;
set ic;
length modcode $ 5;
modcode="&code";
run;

proc append base=out.icnormal11 data=icnormal;
run;


%mend runmix;


%macro main;

    %runmix(feb.normal, ml, 0, , );
*    %runmix(feb.normal, ml, 11a, rvar, rvar);
    %runmix(feb.normal, ml, 11b, rvol, rvol);
*    %runmix(feb.normal, ml, 11c, rvox, rvox);
    %runmix(feb.normal, ml, 11d, rvrv, rvrv);
    %runmix(feb.normal, ml, 11e, rvsu, rvsu);
    %runmix(feb.normal, ml, 11f, rvt5, rvt5);
*    %runmix(feb.normal, ml, 11g, rvt9, rvt9);
    %runmix(feb.normal, ml, 11h, t5ar, t5ar);
    %runmix(feb.normal, ml, 11i, t5ol, t5ol);
    %runmix(feb.normal, ml, 11j, t5ox, t5ox);
    %runmix(feb.normal, ml, 11k, t5su, t5su);
*    %runmix(feb.normal, ml, 11l, t5t5, t5t5);
    %runmix(feb.normal, ml, 11m, t5t9, t5t9);
*    %runmix(feb.normal, ml, 11n, t9ar, t9ar);
    %runmix(feb.normal, ml, 11o, t9ol, t9ol);
*    %runmix(feb.normal, ml, 11p, t9ox, t9ox);
*    %runmix(feb.normal, ml, 11q, t9su, t9su);
    %runmix(feb.normal, ml, 11r, t9t9, t9t9);
    %runmix(feb.normal, ml, 11s, arar, arar);
    %runmix(feb.normal, ml, 11t, arol, arol);
    %runmix(feb.normal, ml, 11u, arox, arox);
    %runmix(feb.normal, ml, 11v, arsu, arsu);
*    %runmix(feb.normal, ml, 11w, olol, olol);
    %runmix(feb.normal, ml, 11x, olox, olox);
    %runmix(feb.normal, ml, 11y, olsu, olsu);
*    %runmix(feb.normal, ml, 11z, suox, suox);
    %runmix(feb.normal, ml, 11*, susu, susu);
*    %runmix(feb.normal, ml, 11+, oxox, oxox);


proc means data=out.icnormal11 noprint;
var aicc;
output out=minic minid(aicc (aicc modcode))=minaicc mincode;
run;

proc print data=minic;
run;

%mend main;

%main
