libname out "c:\ethanol\feb05\renorm\aicc";
libname feb "c:\ethanol\feb05\renorm";

OPTIONS LS=79 ps=59;

proc contents data=feb.normal;
run;

proc datasets library=out;
delete icnormal3;
run;


/* MACRO to run mixed model variants */
/* In all these cases, fixed and random interaction terms are the same (no weights)
so we don't need to have fterms and rterms in macro calls  */

%macro runmix(data, method, code, fterms, extra);


PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ic ;
CLASS NEW;
TITLE "Code &code : NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU T9OX OXOX
               &fterms
               /S DDFM=RES;

RANDOM         int RV T5 T9 AR OL OX SU T9OX OXOX
               &fterms
               /SUB=NEW;
ods output infocrit=ic;
run;

data icnormal;
set ic;
length modcode $ 5;
modcode="&code";
run;

proc append base=out.icnormal3 data=icnormal;
run;


%mend runmix;


%macro main;

    %runmix(feb.normal, ml, 0, , );
    %runmix(feb.normal, ml, 3a, rvar, rvar);
    %runmix(feb.normal, ml, 3b, rvol, rvol);
    %runmix(feb.normal, ml, 3c, rvox, rvox);
    %runmix(feb.normal, ml, 3d, rvrv, rvrv);
    %runmix(feb.normal, ml, 3e, rvsu, rvsu);
    %runmix(feb.normal, ml, 3f, rvt5, rvt5);
    %runmix(feb.normal, ml, 3g, rvt9, rvt9);
    %runmix(feb.normal, ml, 3h, t5ar, t5ar);
    %runmix(feb.normal, ml, 3i, t5ol, t5ol);
    %runmix(feb.normal, ml, 3j, t5ox, t5ox);
    %runmix(feb.normal, ml, 3k, t5su, t5su);
    %runmix(feb.normal, ml, 3l, t5t5, t5t5);
    %runmix(feb.normal, ml, 3m, t5t9, t5t9);
    %runmix(feb.normal, ml, 3n, t9ar, t9ar);
    %runmix(feb.normal, ml, 3o, t9ol, t9ol);
 *   %runmix(feb.normal, ml, 3p, t9ox, t9ox);
    %runmix(feb.normal, ml, 3q, t9su, t9su);
    %runmix(feb.normal, ml, 3r, t9t9, t9t9);
    %runmix(feb.normal, ml, 3s, arar, arar);
    %runmix(feb.normal, ml, 3t, arol, arol);
    %runmix(feb.normal, ml, 3u, arox, arox);
    %runmix(feb.normal, ml, 3v, arsu, arsu);
    %runmix(feb.normal, ml, 3w, olol, olol);
    %runmix(feb.normal, ml, 3x, olox, olox);
    %runmix(feb.normal, ml, 3y, olsu, olsu);
    %runmix(feb.normal, ml, 3z, suox, suox);
    %runmix(feb.normal, ml, 3*, susu, susu);
 *   %runmix(feb.normal, ml, 3+, oxox, oxox);


proc means data=out.icnormal3 noprint;
var aicc;
output out=minic minid(aicc (aicc modcode))=minaicc mincode;
run;

proc print data=minic;
run;

%mend main;

%main
