libname out "c:\ethanol\feb05\renorm\aicc";
libname feb "c:\ethanol\feb05\renorm";

OPTIONS LS=79 ps=59;

proc contents data=feb.normal;
run;

proc datasets library=out;
delete icnormal5;
run;


/* MACRO to run mixed model variants */
/* In all these cases, fixed and random interaction terms are the same (no weights)
so we don't need to have fterms and rterms in macro calls  */

%macro runmix(data, method, code, fterms, extra);


PROC MIXED DATA=&data MAXITER=500 METHOD=&method NOCLPRINT ic ;
CLASS NEW;
TITLE "Code &code : NOx model using &data with method &method and terms &fterms";

MODEL LN_NOX = RV T5 T9 AR OL OX SU T9OX OXOX SUOX T5T5
               &fterms
               /S DDFM=RES;

RANDOM         int RV T5 T9 AR OL OX SU T9OX OXOX SUOX T5T5
               &fterms
               /SUB=NEW;
ods output infocrit=ic;
run;

data icnormal;
set ic;
length modcode $ 5;
modcode="&code";
run;

proc append base=out.icnormal5 data=icnormal;
run;


%mend runmix;


%macro main;

    %runmix(feb.normal, ml, 0, , );
    %runmix(feb.normal, ml, 5a, rvar, rvar);
    %runmix(feb.normal, ml, 5b, rvol, rvol);
    %runmix(feb.normal, ml, 5c, rvox, rvox);
    %runmix(feb.normal, ml, 5d, rvrv, rvrv);
    %runmix(feb.normal, ml, 5e, rvsu, rvsu);
    %runmix(feb.normal, ml, 5f, rvt5, rvt5);
    %runmix(feb.normal, ml, 5g, rvt9, rvt9);
    %runmix(feb.normal, ml, 5h, t5ar, t5ar);
    %runmix(feb.normal, ml, 5i, t5ol, t5ol);
    %runmix(feb.normal, ml, 5j, t5ox, t5ox);
    %runmix(feb.normal, ml, 5k, t5su, t5su);
*    %runmix(feb.normal, ml, 5l, t5t5, t5t5);
    %runmix(feb.normal, ml, 5m, t5t9, t5t9);
    %runmix(feb.normal, ml, 5n, t9ar, t9ar);
    %runmix(feb.normal, ml, 5o, t9ol, t9ol);
*    %runmix(feb.normal, ml, 5p, t9ox, t9ox);
    %runmix(feb.normal, ml, 5q, t9su, t9su);
    %runmix(feb.normal, ml, 5r, t9t9, t9t9);
    %runmix(feb.normal, ml, 5s, arar, arar);
    %runmix(feb.normal, ml, 5t, arol, arol);
    %runmix(feb.normal, ml, 5u, arox, arox);
    %runmix(feb.normal, ml, 5v, arsu, arsu);
    %runmix(feb.normal, ml, 5w, olol, olol);
    %runmix(feb.normal, ml, 5x, olox, olox);
    %runmix(feb.normal, ml, 5y, olsu, olsu);
*    %runmix(feb.normal, ml, 5z, suox, suox);
    %runmix(feb.normal, ml, 5*, susu, susu);
*    %runmix(feb.normal, ml, 5+, oxox, oxox);


proc means data=out.icnormal5 noprint;
var aicc;
output out=minic minid(aicc (aicc modcode))=minaicc mincode;
run;

proc print data=minic;
run;

%mend main;

%main
